@@ -18,11 +18,6 @@ ModemManagerController::ModemManagerController(QObject *parent)
     });
 }
 
-QString ModemManagerController::subsystem()
-{
-    return QStringLiteral("mm");
-}
-
 QString ModemManagerController::equipmentIdentifier(const QString &deviceUni)
 {
     QString equipmentIdentifier;
@@ -44,24 +39,13 @@ void ModemManagerController::ussdInitiate(const QString &deviceUni, const QStrin
     const auto modem = ModemManager::findModemDevice(deviceUni);
     if (modem.isNull()) {
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
-        Q_EMIT ussdErrorReceived(deviceUni, tr("deviceUni not found"));
         return;
     }
-    const auto modem3gppUssdInterface = this->modem3gppUssdInterface(modem);
+    const auto modem3gppUssdInterface = _modem3gppUssdInterface(modem);
     QDBusPendingReply<QString> reply = modem3gppUssdInterface->initiate(command);
-    /*
-        During the following call to waitForFinished(), the DBus client waits for the DBus server to send a reply.
-        In the meantime, the ModemManager instance will send the USSD request and wait for an USSD response.
-        Once the ModemManager instance has received an USSD response, it will send a DBus response as well as a state update, in a possibly undefined order.
-        Even if the state update would be sent before the DBus response, it will be received from this code after the DBus response, as waitForFinished() waits
-       for the correct DBus response and queues any other DBus activity (such as the state update). Hence, the state update will always be received later than
-       waitForFinished() returns. Hence, the ussdInitiateComplete() call will contain the correct message, but the corresponding state update will only happen
-       (milliseconds) later.
-    */
     reply.waitForFinished();
     if (reply.isError()) {
         qDebug() << Q_FUNC_INFO << reply.error();
-        Q_EMIT ussdErrorReceived(deviceUni, reply.error().message());
         return;
     }
     Q_EMIT ussdInitiateComplete(deviceUni, reply.value());
@@ -72,17 +56,10 @@ void ModemManagerController::ussdRespond(const QString &deviceUni, const QString
     const auto modem = ModemManager::findModemDevice(deviceUni);
     if (modem.isNull()) {
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
-        Q_EMIT ussdErrorReceived(deviceUni, tr("deviceUni not found"));
-        return;
-    }
-    const auto modem3gppUssdInterface = this->modem3gppUssdInterface(modem);
-    QDBusPendingReply<QString> dbusReply = modem3gppUssdInterface->respond(reply);
-    dbusReply.waitForFinished();
-    if (dbusReply.isError()) {
-        qDebug() << Q_FUNC_INFO << dbusReply.error();
-        Q_EMIT ussdErrorReceived(deviceUni, dbusReply.error().message());
         return;
     }
+    const auto modem3gppUssdInterface = _modem3gppUssdInterface(modem);
+    modem3gppUssdInterface->respond(reply);
 }
 
 void ModemManagerController::ussdCancel(const QString &deviceUni)
@@ -90,10 +67,9 @@ void ModemManagerController::ussdCancel(const QString &deviceUni)
     const auto modem = ModemManager::findModemDevice(deviceUni);
     if (modem.isNull()) {
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
-        Q_EMIT ussdErrorReceived(deviceUni, tr("deviceUni not found"));
         return;
     }
-    const auto modem3gppUssdInterface = this->modem3gppUssdInterface(modem);
+    const auto modem3gppUssdInterface = _modem3gppUssdInterface(modem);
     modem3gppUssdInterface->cancel();
 }
 
@@ -105,7 +81,7 @@ QString ModemManagerController::callNumber(const QString &deviceUni, const QStri
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
         return callNumber;
     }
-    const auto voiceInterface = this->voiceInterface(modem);
+    const auto voiceInterface = _voiceInterface(modem);
     if (voiceInterface.isNull()) {
         qDebug() << Q_FUNC_INFO << "voiceInterface not found";
         return callNumber;
@@ -126,7 +102,7 @@ void ModemManagerController::createCall(const QString &deviceUni, const QString
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
         return;
     }
-    const auto voiceInterface = this->voiceInterface(modem);
+    const auto voiceInterface = _voiceInterface(modem);
     if (voiceInterface.isNull()) {
         qDebug() << Q_FUNC_INFO << "voiceInterface not found";
         return;
@@ -146,7 +122,7 @@ void ModemManagerController::acceptCall(const QString &deviceUni, const QString
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
         return;
     }
-    const auto voiceInterface = this->voiceInterface(modem);
+    const auto voiceInterface = _voiceInterface(modem);
     if (voiceInterface.isNull()) {
         qDebug() << Q_FUNC_INFO << "voiceInterface not found";
         return;
@@ -166,7 +142,7 @@ void ModemManagerController::hangUp(const QString &deviceUni, const QString &cal
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
         return;
     }
-    const auto voiceInterface = this->voiceInterface(modem);
+    const auto voiceInterface = _voiceInterface(modem);
     if (voiceInterface.isNull()) {
         qDebug() << Q_FUNC_INFO << "voiceInterface not found";
         return;
@@ -186,7 +162,7 @@ void ModemManagerController::sendDtmf(const QString &deviceUni, const QString &c
         qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
         return;
     }
-    const auto voiceInterface = this->voiceInterface(modem);
+    const auto voiceInterface = _voiceInterface(modem);
     if (voiceInterface.isNull()) {
         qDebug() << Q_FUNC_INFO << "voiceInterface not found";
         return;
@@ -205,9 +181,9 @@ void ModemManagerController::sendDtmf(const QString &deviceUni, const QString &c
 DialerTypes::CallDataVector ModemManagerController::fetchCalls()
 {
     DialerTypes::CallDataVector callDataVector;
-    auto calls = m_calls;
+    auto calls = _calls;
     for (auto callObject : calls) {
-        auto callData = voiceCallData(callObject);
+        auto callData = _voiceCallData(callObject);
         callDataVector.append(callData);
     }
     return callDataVector;
@@ -216,25 +192,27 @@ DialerTypes::CallDataVector ModemManagerController::fetchCalls()
 DialerTypes::CallData ModemManagerController::getCall(const QString &deviceUni, const QString &callUni)
 {
     DialerTypes::CallData callData;
-    auto callObject = getVoiceCallObject(deviceUni, callUni);
+    auto callObject = _getVoiceCallObject(deviceUni, callUni);
     if (callObject) {
-        callData = voiceCallData(callObject);
+        callData = _voiceCallData(callObject);
     }
     return callData;
 }
 
 void ModemManagerController::deleteCall(const QString &deviceUni, const QString &callUni)
 {
-    Q_UNUSED(deviceUni) // TODO: improve deviceUni getter
-    for (const QSharedPointer<ModemManager::ModemDevice> &modemDevice : ModemManager::modemDevices()) {
-        const auto voiceInterface = this->voiceInterface(modemDevice);
-        if (voiceInterface.isNull()) {
-            qDebug() << Q_FUNC_INFO << "voiceInterface not found";
-            continue;
-        }
-        qDebug() << Q_FUNC_INFO << "deleting voice call" << callUni << "via" << modemDevice->uni();
-        voiceInterface->deleteCall(callUni);
+    const auto modem = ModemManager::findModemDevice(deviceUni);
+    if (modem.isNull()) {
+        qDebug() << Q_FUNC_INFO << "deviceUni not found:" << deviceUni;
+        return;
     }
+    const auto voiceInterface = _voiceInterface(modem);
+    if (voiceInterface.isNull()) {
+        qDebug() << Q_FUNC_INFO << "voiceInterface not found";
+        return;
+    }
+    qDebug() << Q_FUNC_INFO << "deleting call" << deviceUni << callUni;
+    voiceInterface->deleteCall(callUni);
 }
 
 void ModemManagerController::onServiceAppeared()
@@ -266,7 +244,7 @@ void ModemManagerController::init()
     for (const auto &device : modemDevices) {
         appendDeviceUni(device->uni());
         // 3GPP
-        const auto modem3gppInterface = this->modem3gppInterface(device);
+        const auto modem3gppInterface = _modem3gppInterface(device);
         if (modem3gppInterface.isNull()) {
             qDebug() << "Skipping 3GPP-related connections";
             continue;
@@ -276,7 +254,7 @@ void ModemManagerController::init()
         });
 
         // 3GPPUSSD
-        const auto modem3gppUssdInterface = this->modem3gppUssdInterface(device);
+        const auto modem3gppUssdInterface = _modem3gppUssdInterface(device);
         if (modem3gppInterface.isNull()) {
             qDebug() << "Skipping USSD-related connections";
             continue;
@@ -309,7 +287,7 @@ void ModemManagerController::init()
         });
 
         // Voice
-        const auto voiceInterface = this->voiceInterface(device);
+        const auto voiceInterface = _voiceInterface(device);
         if (voiceInterface.isNull()) {
             qDebug() << "Skipping Voice-related connections";
             continue;
@@ -317,10 +295,10 @@ void ModemManagerController::init()
         connect(voiceInterface.get(), &ModemManager::ModemVoice::callAdded, this, [this, device, voiceInterface](const QString &callUni) {
             qDebug() << Q_FUNC_INFO << "call added, initiating";
             ModemManager::Call::Ptr call = voiceInterface->findCall(callUni);
-            initAddedCall(device, call);
+            _initAddedCall(device, call);
         });
         connect(voiceInterface.get(), &ModemManager::ModemVoice::callDeleted, this, [this, device](const QString &callUni) {
-            removeCall(callUni);
+            _removeCall(callUni);
             Q_EMIT callDeleted(device->uni(), callUni);
         });
 
@@ -337,37 +315,37 @@ void ModemManagerController::init()
         });
     }
 
-    fetchModemCalls();
+    _fetchModemCalls();
 }
 
-void ModemManagerController::removeCall(const QString &callId)
+void ModemManagerController::_removeCall(const QString &callId)
 {
-    m_calls.erase(std::remove_if(m_calls.begin(),
-                                 m_calls.end(),
-                                 [callId](CallObject *callObject) {
-                                     return (callObject->id() == callId);
-                                 }),
-                  m_calls.end());
+    _calls.erase(std::remove_if(_calls.begin(),
+                                _calls.end(),
+                                [callId](CallObject *callObject) {
+                                    return (callObject->id() == callId);
+                                }),
+                 _calls.end());
 }
 
-QSharedPointer<ModemManager::Modem3gpp> ModemManagerController::modem3gppInterface(const QSharedPointer<ModemManager::ModemDevice> modemDevice)
+QSharedPointer<ModemManager::Modem3gpp> ModemManagerController::_modem3gppInterface(const QSharedPointer<ModemManager::ModemDevice> modemDevice)
 {
     return modemDevice->interface(ModemManager::ModemDevice::GsmInterface).objectCast<ModemManager::Modem3gpp>();
 }
 
-QSharedPointer<ModemManager::Modem3gppUssd> ModemManagerController::modem3gppUssdInterface(const QSharedPointer<ModemManager::ModemDevice> modemDevice)
+QSharedPointer<ModemManager::Modem3gppUssd> ModemManagerController::_modem3gppUssdInterface(const QSharedPointer<ModemManager::ModemDevice> modemDevice)
 {
     return modemDevice->interface(ModemManager::ModemDevice::GsmUssdInterface).objectCast<ModemManager::Modem3gppUssd>();
 }
 
-QSharedPointer<ModemManager::ModemVoice> ModemManagerController::voiceInterface(const QSharedPointer<ModemManager::ModemDevice> modemDevice)
+QSharedPointer<ModemManager::ModemVoice> ModemManagerController::_voiceInterface(const QSharedPointer<ModemManager::ModemDevice> modemDevice)
 {
     return modemDevice->interface(ModemManager::ModemDevice::VoiceInterface).objectCast<ModemManager::ModemVoice>();
 }
 
-CallObject *ModemManagerController::voiceCallObject(const QSharedPointer<ModemManager::ModemDevice> &device,
-                                                    const QSharedPointer<ModemManager::Call> &call,
-                                                    QObject *parent)
+CallObject *ModemManagerController::_voiceCallObject(const QSharedPointer<ModemManager::ModemDevice> &device,
+                                                     const QSharedPointer<ModemManager::Call> &call,
+                                                     QObject *parent)
 {
     auto callObject = new CallObject(parent);
     callObject->setId(call->uni());
@@ -384,7 +362,7 @@ CallObject *ModemManagerController::voiceCallObject(const QSharedPointer<ModemMa
     return callObject;
 }
 
-DialerTypes::CallData ModemManagerController::voiceCallData(CallObject *callObject)
+DialerTypes::CallData ModemManagerController::_voiceCallData(CallObject *callObject)
 {
     DialerTypes::CallData callData;
     callData.id = callObject->id();
@@ -404,32 +382,32 @@ DialerTypes::CallData ModemManagerController::voiceCallData(CallObject *callObje
     return callData;
 }
 
-void ModemManagerController::fetchModemCalls()
+void ModemManagerController::_fetchModemCalls()
 {
-    m_calls.clear();
+    _calls.clear();
     const auto modemDevices = ModemManager::modemDevices();
     if (modemDevices.isEmpty()) {
         qWarning() << "Could not find modem devices";
         return;
     }
     for (const auto &device : modemDevices) {
-        const auto voiceInterface = this->voiceInterface(device);
+        const auto voiceInterface = this->_voiceInterface(device);
         if (voiceInterface.isNull()) {
             qDebug() << "Skipping device without voice interface";
             continue;
         }
         const auto voiceCalls = voiceInterface->calls();
         for (const auto &call : voiceCalls) {
-            initAddedCall(device, call);
+            _initAddedCall(device, call);
         };
     };
 }
 
-CallObject *ModemManagerController::getVoiceCallObject(const QString &deviceUni, const QString &callUni)
+CallObject *ModemManagerController::_getVoiceCallObject(const QString &deviceUni, const QString &callUni)
 {
     Q_UNUSED(deviceUni);
     DialerTypes::CallData callData;
-    auto calls = m_calls;
+    auto calls = _calls;
     for (auto callObject : calls) {
         if (callObject->id() == callUni) {
             return callObject;
@@ -438,15 +416,11 @@ CallObject *ModemManagerController::getVoiceCallObject(const QString &deviceUni,
     return nullptr;
 }
 
-void ModemManagerController::initAddedCall(const QSharedPointer<ModemManager::ModemDevice> &device, const QSharedPointer<ModemManager::Call> &call)
+void ModemManagerController::_initAddedCall(const QSharedPointer<ModemManager::ModemDevice> &device, const QSharedPointer<ModemManager::Call> &call)
 {
     qDebug() << Q_FUNC_INFO << "call details:" << call->direction() << call->state() << call->stateReason();
-    if (getVoiceCallObject(device->uni(), call->uni())) {
-        // voice call object already exists, we do not need to append to list again
-        return;
-    }
-    auto voiceCallObject = this->voiceCallObject(device, call, this);
-    m_calls.append(voiceCallObject);
+    auto voiceCallObject = _voiceCallObject(device, call, this);
+    _calls.append(voiceCallObject);
     connect(call.get(),
             &ModemManager::Call::stateChanged,
             this,
@@ -459,7 +433,7 @@ void ModemManagerController::initAddedCall(const QSharedPointer<ModemManager::Mo
                 if (voiceCallObject) {
                     voiceCallObject->onCallStateChanged(device->uni(), call->uni(), callDirection, callState, callReason);
                 }
-                Q_EMIT callStateChanged(voiceCallData(voiceCallObject));
+                Q_EMIT callStateChanged(device->uni(), call->uni(), callDirection, callState, callReason);
             });
     Q_EMIT callAdded(device->uni(),
                      call->uni(),
